@@ -7,13 +7,19 @@ __all__ = [
 
 def image_processing(param, analyse_morpho=True):
 
+    # 3rd party import
     from pathlib import Path
+    import pandas as pd
+    
+    # Inernal import
+    from ./image_features_extract import read_image,gaussian_flattening
+    from ./image_features_extract import xRemoveSpriesHorizontal, Otsu_tresholding
 
     # lecture de l'image
     im_brute, n_row, n_col = read_image(param["repertoire"] / param["file"])
 
     # mise à plat de l'image
-    im_flat = gaussian_flattening(im_brute, sigma=param["sigma"])
+    im_flat = gaussian_flattening(im_brute, param["sigma"])
     # im_flat = poly_flattening(im_brute)
 
     # supression des traces verticales
@@ -44,7 +50,7 @@ def make_tex_document(
     flag=False,
     new_section=False,
 ):
-
+    # 3rd party import
     import numpy as np
     import matplotlib.pyplot as plt
     import matplotlib
@@ -219,6 +225,7 @@ def make_tex_document(
 
 def build_bbox(param, size_min=50, method="ge"):
 
+    # 3rd party import
     import pandas as pd
     from pathlib import Path
 
